Changelog
==============

1.3.0
------
* Updated jQuery UI to v1.11.0
* Updated TWBS to v3.2.0

1.2.0
------
* Fixed jquery.dataTables CSS loading as a script.
* Fixed URL to TWBS Glyphicons.
* Added TWBS CSS maps.
* Updated Modernizr to v2.8.2
* Updated Normalize.css to v3.0.1
* Updated jQuery to v1.11.1 and 2.1.1
* Added jQuery map.
* Updated jquery.dataTables to v1.10.0
* Updated jquery.scrollTo to v1.4.12
* Updated FontAwesome to v4.1.0


1.1.0
------
* Updated Twitter Bootstrap to v3.1.1
* Updated Normalize.css to v3.0.0
* Updated jquery.scrollTo to v1.4.11

1.0.0
------
* Removed famfamfam Silk Icons.
* Updated Fontawesome to v4.0.3.
* Removed Fontawesome's IE7 CSS.
* Removed djfrontend_fontawesome_ie template tag.
* Updated Twitter Bootstrap to v3.0.3.
* Updated Modernizr to v2.7.1.
* Updated jQuery.ScrollTo to v1.4.9.
* Updated jQuery.smooth-scroll to v1.4.13.
* Updated jQuery to v1.11.0.
* Updated jQuery to v2.1.0.
* Updated jQuery UI v1.10.3 to v1.10.4.
* Changed template arguments to optional arguments.
* Allow settings to override defaults.
* Load CDN for all non-local JavaScript
* Included tests and Travis CI integration.
* Removed conditional HTML classes.
* Updated IE warning and added ie-warning class.
* Added meta_viewport block.
* Updated H5BP CSS to master.
* Updated Normalize.css to v2.1.3.
* Updated Google Analytics snippets to Universal Analytics.

0.4.0
------
* Updated jQuery Smooth Scroll to v1.4.12.
* Updated h5bp.css to v4.3.0.
* Updated Normalize.css to v1.1.3.
* Removed Chrome Frame value from meta content attribute.
* Added initial CDNJS load for jQuery Dynamic Formset, jQuery ScrollTo and jQuery Smooth Scroll.
* Added Font Awesome (3.2.1).
* Added djfront_fontawesome template tag.
* Added djfront_fontawesome_ie template tag.
* Fixed jQuery UI initial load.

0.3.1
------
* Fixed URL to TWBS Glyphicons in bootstrap.min.css

0.3.0
------
* Updated Twitter Bootstrap to v3.0.0
* Added djfrontend_twbs_theme_css template tag
* Added bootstrap-theme.css and bootstrap-theme.min.css
* Added djfrontend_jquery_scrollto template tag
* Added jquery.scrollTo.js and jquery.scrollTo.min.js
* Removed djfrontend_twbs_glyphicons template tag
* Removed bootstrap-glyphicons.css

0.2.1
------
* Updated Twitter Bootstrap to v3.0.0 RC2

0.2.0
------
* Updated jQuery to v1.10.2 and v2.0.3
* Updated Twitter Bootstrap to v3.0.0 RC1
* Added djfrontend_twbs_glyphicons template tag
* Added cdnjs initial loading for Modernizr and jQuery DataTables
* Removed djfrontend_twbs_responsive_css template tag
* Removed bootstrap-typeahead.js

0.1.0
------
* Initial release
